========================
Apache Spark Integration
========================

The :mod:`pysail.spark` module provides integration with Apache Spark.

.. currentmodule:: pysail.spark

.. autosummary::
    :toctree: api/

    SparkConnectServer
